0.1.6
-----

* Font handling bug fix.
* More tests.

0.1.5
------

* Table rendering fix.

0.1.04
------

* Added missing files in MANIFEST.in

0.1.03
------

* Various bug fixes and refactoring.

0.1.02
------

* Table cell rendering fix.

0.1.01
------

* Major rewrite of parser and drawing code to be more forgiving for broken HTML.
